@@ -148,13 +148,20 @@ dialog_response_handler (GtkDialog              *dlg,
 			 gint                    res_id,
 			 GeditPreferencesDialog *dialog)
 {
+	GError *error = NULL;
+
 	gedit_debug (DEBUG_PREFS, "");
 
 	switch (res_id) {
 		case GTK_RESPONSE_HELP:
-			/* TODO */;
+			gnome_help_display ("gedit.xml", "gedit-prefs", &error);
+			if (error != NULL)
+			{
+				gedit_warning (GTK_WINDOW (dlg), error->message);
+				g_error_free (error);
+			}
 			break;
-			
+
 		default:
 			gtk_widget_destroy (dialog->dialog);
 	}
@@ -852,6 +859,9 @@ get_selected_style (GeditPreferencesDialog *dlg)
 	style = gtk_source_language_get_tag_style (lang, id);
 	def_style = gtk_source_language_get_tag_default_style (lang, id);
 
+	if (style == NULL)
+		return def_style;
+
 	style->is_default = TRUE;
 	def_style->is_default = TRUE;
 
@@ -863,69 +873,6 @@ get_selected_style (GeditPreferencesDialog *dlg)
 	return style;
 }
 
-static void
-styles_cb (GtkWidget              *treeview,
-	   GeditPreferencesDialog *dlg)
-{
-	GtkSourceTagStyle *style;
-
-	style = get_selected_style (dlg);
-	g_return_if_fail (style != NULL);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->bold_togglebutton),
-				      style->bold);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->italic_togglebutton),
-				      style->italic);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->underline_togglebutton),
-				      style->underline);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->strikethrough_togglebutton),
-				      style->strikethrough);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->foreground_checkbutton),
-				      style->mask & GTK_SOURCE_TAG_STYLE_USE_FOREGROUND);
-
-	if ((style->mask & GTK_SOURCE_TAG_STYLE_USE_FOREGROUND) == GTK_SOURCE_TAG_STYLE_USE_FOREGROUND)
-	{
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->foreground_colorbutton),
-					    &style->foreground);
-	}
-	else
-	{
-		GdkColor text_color;
-		
-		text_color = gedit_prefs_manager_get_text_color ();
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->foreground_colorbutton),
-					    &text_color);
-	}
-	
-	gtk_widget_set_sensitive (dlg->foreground_colorbutton, 
-				  style->mask & GTK_SOURCE_TAG_STYLE_USE_FOREGROUND);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->background_checkbutton),
-				      style->mask & GTK_SOURCE_TAG_STYLE_USE_BACKGROUND);
-	
-	if ((style->mask & GTK_SOURCE_TAG_STYLE_USE_BACKGROUND) == GTK_SOURCE_TAG_STYLE_USE_BACKGROUND)
-	{
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->background_colorbutton_2),
-					    &style->background);
-	}
-	else
-	{
-		GdkColor background_color;
-		
-		background_color = gedit_prefs_manager_get_background_color ();
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->background_colorbutton_2),
-					    &background_color);
-	}
-
-	gtk_widget_set_sensitive (dlg->background_colorbutton_2, 
-				  style->mask & GTK_SOURCE_TAG_STYLE_USE_BACKGROUND);
-
-	gtk_widget_set_sensitive (dlg->reset_button, !style->is_default);
-
-	gtk_source_tag_style_free (style);
-}
-
 static void
 style_button_toggled (GtkToggleButton        *button,
 		      GeditPreferencesDialog *dlg)
@@ -947,6 +894,10 @@ style_button_toggled (GtkToggleButton        *button,
 	lang = get_selected_language (dlg);
 
 	style = gtk_source_language_get_tag_style (lang, id);
+	if (style == NULL)
+	{
+		style = gtk_source_tag_style_new ();
+	}
 
 	new_style = gtk_source_tag_style_copy (style);
 	
@@ -1029,6 +980,105 @@ style_color_set (GtkColorButton         *button,
 	style_button_toggled (NULL, dlg);
 }
 
+static void
+styles_cb (GtkWidget              *treeview,
+	   GeditPreferencesDialog *dlg)
+{
+	GtkSourceTagStyle *style;
+
+	style = get_selected_style (dlg);
+	g_return_if_fail (style != NULL);
+
+	/* we must block callbacks while setting the new values */
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->bold_togglebutton),
+					 G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->italic_togglebutton),
+					 G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->underline_togglebutton),
+					 G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->strikethrough_togglebutton),
+					 G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->foreground_checkbutton), 
+					 G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->background_checkbutton), 
+					 G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->foreground_colorbutton),
+					 G_CALLBACK (style_color_set), dlg);
+	g_signal_handlers_block_by_func (G_OBJECT (dlg->background_colorbutton_2), 
+					 G_CALLBACK (style_color_set), dlg);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->bold_togglebutton),
+				      style->bold);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->italic_togglebutton),
+				      style->italic);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->underline_togglebutton),
+				      style->underline);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->strikethrough_togglebutton),
+				      style->strikethrough);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->foreground_checkbutton),
+				      style->mask & GTK_SOURCE_TAG_STYLE_USE_FOREGROUND);
+
+	if ((style->mask & GTK_SOURCE_TAG_STYLE_USE_FOREGROUND) == GTK_SOURCE_TAG_STYLE_USE_FOREGROUND)
+	{
+		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->foreground_colorbutton),
+					    &style->foreground);
+	}
+	else
+	{
+		GdkColor text_color;
+		
+		text_color = gedit_prefs_manager_get_text_color ();
+		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->foreground_colorbutton),
+					    &text_color);
+	}
+	
+	gtk_widget_set_sensitive (dlg->foreground_colorbutton, 
+				  style->mask & GTK_SOURCE_TAG_STYLE_USE_FOREGROUND);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->background_checkbutton),
+				      style->mask & GTK_SOURCE_TAG_STYLE_USE_BACKGROUND);
+	
+	if ((style->mask & GTK_SOURCE_TAG_STYLE_USE_BACKGROUND) == GTK_SOURCE_TAG_STYLE_USE_BACKGROUND)
+	{
+		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->background_colorbutton_2),
+					    &style->background);
+	}
+	else
+	{
+		GdkColor background_color;
+		
+		background_color = gedit_prefs_manager_get_background_color ();
+		gtk_color_button_set_color (GTK_COLOR_BUTTON (dlg->background_colorbutton_2),
+					    &background_color);
+	}
+
+	gtk_widget_set_sensitive (dlg->background_colorbutton_2, 
+				  style->mask & GTK_SOURCE_TAG_STYLE_USE_BACKGROUND);
+
+	gtk_widget_set_sensitive (dlg->reset_button, !style->is_default);
+
+	/* reenable callbacks */
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->bold_togglebutton),
+					   G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->italic_togglebutton),
+					   G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->underline_togglebutton),
+					   G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->strikethrough_togglebutton),
+					   G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->foreground_checkbutton), 
+					   G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->background_checkbutton), 
+					   G_CALLBACK (style_button_toggled), dlg);
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->foreground_colorbutton),
+					   G_CALLBACK (style_color_set), dlg);
+	g_signal_handlers_unblock_by_func (G_OBJECT (dlg->background_colorbutton_2), 
+					   G_CALLBACK (style_color_set), dlg);
+
+	gtk_source_tag_style_free (style);
+}
+
 static void
 reset_button_clicked (GtkButton              *button, 
 		      GeditPreferencesDialog *dlg)
