@@ -34,6 +34,7 @@
 
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcebuffer.h>
+#include <libgnomevfs/gnome-vfs-result.h>
 
 #include <gedit/gedit-encodings.h>
 
@@ -83,24 +84,31 @@ struct _GeditDocumentClass
 	GtkSourceBufferClass parent_class;
 
 	/* File name (uri) changed */
-	void (* name_changed)		(GeditDocument *document);
+	void (* name_changed)		(GeditDocument    *document);
 
+	/* Connect to the followinf two signals for loading and reverting */
 	/* Document loaded */
-	void (* loaded)			(GeditDocument *document);
+	void (* loaded)			(GeditDocument    *document,
+					 const GError     *error);
+
+	void (* loading)		(GeditDocument    *document,
+					 gulong            size,
+					 gulong            total_size);
 
 	/* Document saved */
-	void (* saved)  		(GeditDocument *document);	
+	void (* saved)  		(GeditDocument    *document);	
 
 	/* Readonly flag changed */
-	void (* readonly_changed)	(GeditDocument *document,
-					 gboolean readonly);
+	void (* readonly_changed)	(GeditDocument    *document,
+					 gboolean          readonly);
 
 	/* Find state udpated */
-	void (* can_find_again) 	(GeditDocument *document);
+	void (* can_find_again) 	(GeditDocument    *document);
 };
 
 #define GEDIT_ERROR_INVALID_UTF8_DATA 	1024
-#define GEDIT_ERROR_UNTITLED		1025	
+#define GEDIT_ERROR_UNTITLED		1025
+#define GEDIT_ERROR_NOT_REGULAR_FILE	1026
 #define GEDIT_DOCUMENT_IO_ERROR gedit_document_io_error_quark ()
 
 GQuark 		gedit_document_io_error_quark (void);
@@ -109,8 +117,7 @@ GType        	gedit_document_get_type      	(void) G_GNUC_CONST;
 
 GeditDocument*	gedit_document_new 		(void);
 GeditDocument* 	gedit_document_new_with_uri 	(const gchar          *uri, 
-						 const GeditEncoding  *encoding,
-						 GError              **error);
+						 const GeditEncoding  *encoding);
 
 void 		gedit_document_set_readonly 	(GeditDocument        *doc, 
 						 gboolean              readonly);
@@ -120,10 +127,9 @@ gchar*		gedit_document_get_raw_uri 	(const GeditDocument *doc);
 gchar*		gedit_document_get_uri 		(const GeditDocument *doc);
 gchar*		gedit_document_get_short_name 	(const GeditDocument *doc);
 
-gboolean	gedit_document_load 		(GeditDocument        *doc, 
+void		gedit_document_load 		(GeditDocument        *doc, 
 						 const gchar          *uri, 
-						 const GeditEncoding  *encoding,
-						 GError              **error);
+						 const GeditEncoding  *encoding);
 
 gboolean	gedit_document_load_from_stdin 	(GeditDocument        *doc, 
 						 GError              **error);
@@ -137,18 +143,12 @@ gboolean	gedit_document_save_as 		(GeditDocument        *doc,
 						 const GeditEncoding  *encoding,
 						 GError              **error);
 
-gboolean	gedit_document_save_a_copy_as 	(GeditDocument        *doc,
-						 const gchar          *uri, 
-						 const GeditEncoding  *encoding,
-						 GError              **error);
-
-gboolean 	gedit_document_revert 		(GeditDocument *doc,  GError **error);
+void	 	gedit_document_revert 		(GeditDocument *doc);
 
 gboolean	gedit_document_is_untitled 	(const GeditDocument* doc);
 gboolean	gedit_document_get_modified 	(const GeditDocument* doc);
 
-gint		gedit_document_get_char_count	(const GeditDocument *doc);
-gint		gedit_document_get_line_count 	(const GeditDocument *doc);
+gboolean	gedit_document_get_deleted	(GeditDocument *doc);
 		
 void		gedit_document_insert_text	(GeditDocument *doc, 
 						 gint	        pos,
@@ -159,9 +159,6 @@ void		gedit_document_insert_text_at_cursor (GeditDocument *doc,
                                                  const gchar   *text,
                                                  gint           len);
 
-gint		gedit_document_get_cursor (GeditDocument *doc);
-void		gedit_document_set_cursor (GeditDocument *doc, gint cursor);
-
 void 		gedit_document_delete_text 	(GeditDocument *doc, 
 		                                 gint start, gint end);
 
@@ -207,8 +204,6 @@ gboolean	gedit_document_replace_all 	(GeditDocument *doc,
 				            	 const gchar *find, 
 						 const gchar *replace, 
 					    	 gint flags);
-guint		gedit_document_get_line_at_offset (const GeditDocument *doc, guint offset);
-
 void		gedit_document_set_selection 	(GeditDocument *doc, 
 						 gint start, 
 						 gint end);
@@ -219,6 +214,9 @@ GtkSourceLanguage *gedit_document_get_language 	(GeditDocument *doc);
 
 const GeditEncoding *gedit_document_get_encoding (GeditDocument *doc);
 
+glong		gedit_document_get_seconds_since_last_save_or_load 
+						(GeditDocument *doc);
+
 #endif /* __GEDIT_DOCUMENT_H__ */
 
 
