@@ -38,7 +38,7 @@
 
 void 		gedit_file_new 		(void);
 void 		gedit_file_open 	(GeditMDIChild *active_child);
-void 		gedit_file_close 	(GtkWidget *view);
+gboolean	gedit_file_close 	(GtkWidget *view);
 gboolean	gedit_file_save 	(GeditMDIChild *child, gboolean force);
 gboolean 	gedit_file_save_as 	(GeditMDIChild *child);
 void		gedit_file_save_all 	(void);
@@ -46,7 +46,7 @@ gboolean	gedit_file_close_all 	(void);
 void		gedit_file_exit 	(void);
 void		gedit_file_revert 	(GeditMDIChild *child);
 
-gboolean 	gedit_file_open_uri_list (GSList* uri_list, gint line, gboolean create);
+gboolean 	gedit_file_open_uri_list (GSList* uri_list, const GeditEncoding *encoding, gint line_pos, gboolean create);
 gboolean 	gedit_file_open_recent   (EggRecentView *view, EggRecentItem *item, gpointer data);
 gboolean 	gedit_file_open_single_uri (const gchar* uri, const GeditEncoding *encoding);
 
