@@ -44,6 +44,7 @@
 #include "gedit-mdi.h"
 #include "gedit-prefs-manager-app.h"
 #include "gedit-debug.h"
+#include "gedit-encodings.h"
 #include "gedit-file.h"
 #include "gedit-utils.h"
 #include "gedit-session.h"
@@ -57,10 +58,9 @@
 #endif
 
 GeditMDI *gedit_mdi = NULL;
-gboolean gedit_close_x_button_pressed = FALSE;
-gboolean gedit_exit_button_pressed = FALSE; 
 BonoboObject *gedit_app_server = NULL;
 
+static gchar *encoding_charset = NULL;
 static gboolean quit_option = FALSE;
 static gboolean new_window_option = FALSE;
 static gboolean new_document_option = FALSE;
@@ -70,6 +70,10 @@ typedef struct _CommandLineData CommandLineData;
 struct _CommandLineData
 {
 	GSList* file_list;
+
+	/* note that encoding is const and should not be freed */
+	const GeditEncoding *encoding;
+
 	gint line_pos;
 };
 
@@ -78,6 +82,9 @@ static void gedit_load_file_list (CommandLineData *data);
 
 static const struct poptOption options [] =
 {
+	{ "encoding", '\0', POPT_ARG_STRING, &encoding_charset,	0,
+	  N_("Set the character encoding to be used to open the files listed on the command line"), NULL },
+
 	{ "quit", '\0', POPT_ARG_NONE, &quit_option, 0,
 	  N_("Quit an existing instance of gedit"), NULL },
 
@@ -115,17 +122,16 @@ gedit_load_file_list (CommandLineData *data)
 	while (gtk_events_pending ())
 		gtk_main_iteration ();
 
-	gedit_file_new ();
-
 	res = gedit_file_open_from_stdin (NULL);
 
 	if (data == NULL) 
 	{
+		gedit_file_new ();
 		return;
 	}
-	
+
 	/* Load files */
-	gedit_file_open_uri_list (data->file_list, data->line_pos, TRUE);
+	gedit_file_open_uri_list (data->file_list, data->encoding, data->line_pos, TRUE);
 	
 	g_slist_foreach (data->file_list, (GFunc)g_free, NULL);
 	g_slist_free (data->file_list);
@@ -168,8 +174,15 @@ gedit_get_command_line_data (GnomeProgram *program)
 		}
 
 		data->file_list = g_slist_reverse (data->file_list);
+
+		if (encoding_charset)
+		{
+			data->encoding = gedit_encoding_get_from_charset (encoding_charset);
+			if (data->encoding == NULL)
+				g_print (_("The specified encoding \"%s\" is not valid\n"), encoding_charset);
+		}
 	}
-		
+
 	return data;
 }
 
@@ -410,19 +423,12 @@ gedit_get_active_document (void)
 	return GEDIT_MDI_CHILD (active_child)->document;
 }
 
-GeditView *
+GtkWidget *
 gedit_get_active_view (void)
 {
-	GtkWidget *active_view;
-
 	g_return_val_if_fail (gedit_mdi != NULL, NULL);
 
-	active_view = bonobo_mdi_get_active_view (BONOBO_MDI (gedit_mdi));
-	
-	if (active_view == NULL)
-		return NULL;
-
-	return GEDIT_VIEW (active_view);
+	return bonobo_mdi_get_active_view (BONOBO_MDI (gedit_mdi));
 }
 
 GList * 
@@ -445,8 +451,8 @@ gedit_get_ui_component_from_window (BonoboWindow* win)
 GList *
 gedit_get_open_documents (void)
 {
-	GList* children;
-	GList* docs = NULL;
+	GList *children;
+	GList *docs = NULL;
 	g_return_val_if_fail (gedit_mdi != NULL, NULL);
 
 	children = bonobo_mdi_get_children (BONOBO_MDI (gedit_mdi));
@@ -456,12 +462,12 @@ gedit_get_open_documents (void)
 		GeditMDIChild *child;
 
 		child = GEDIT_MDI_CHILD (children->data);
-		
-		docs = g_list_append (docs, child->document);
+
+		docs = g_list_prepend (docs, child->document);
 		children = g_list_next (children);
 	}
-	
-	return docs;
+
+	return g_list_reverse (docs);
 }
 
 GeditMDI *
